CiontekPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CiontekPlatform
Implementers

Constructors

CiontekPlatform()
Constructs a CiontekPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPrinterStatus() Future<PrinterStatus>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printLine(CiontekPrintLine line) Future<PrintResult>
printLines(List<CiontekPrintLine> lines) Future<PrintResult>
setFontPath(String path) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CiontekPlatform
The default instance of CiontekPlatform to use.
getter/setter pair